## [0.0.17]
- Stability
- Meshagent cli 

## [0.0.16]
- Stability

## [0.0.15]
- Stability

## [0.0.14]
- Stability

## [0.0.11]
- Stability

## [0.0.10]
- Stability

## [0.0.9]
- Stability

## [0.0.8]
- Stability 

## [0.0.7]
- Added code editor agent
- Fixes

## [0.0.6]
- Fixes

## [0.0.5]
- Fix chatbox initialization

## [0.0.4]
- Streaming support